<?php

class Application_Model_Api_Util {
    
    const SECRET_KEY = 'VMWNCgyrlY0D2kV8';
    
    const STATUS_CODE_SUCCESS = 200;
    const STATUS_CODE_SUCCESS_LABEL = 'Success';
    const STATUS_CODE_ERROR = 500;
    const STATUS_CODE_SUCCESS_ERROR = 'Error';
    const STATUS_CODE_UNAUTH = 400;
    const STATUS_CODE_UNAUTH_LABEL = 'Unauthorized Access';
    const STATUS_CODE_NOTFOUND = 404;
    const STATUS_CODE_NOTFOUND_LABEL = 'Not Found';
    
    public static function get($url) {
        $client = new Zend_Http_Client($url, array('timeout' => 180));
        $client->request('GET');
        $response = self::decode($client->request()->getBody());
        return $response;
    }
    
    public static function post($url, $data, $message = null, $status = self::STATUS_CODE_SUCCESS, $label = self::STATUS_CODE_SUCCESS_LABEL) {
        $client = new Zend_Http_Client($url, array('timeout' => 180));
        $client->setRawData(self::encode($data, $message, $status, $label), 'application/json')->request('POST');
        $response = self::decode($client->request()->getBody());
        return $response;
    }
    
    public static function encode($data, $message = null, $status = self::STATUS_CODE_SUCCESS, $label = self::STATUS_CODE_SUCCESS_LABEL) {
        $response = array('status'=>$status, 'label'=>$label, 'message'=>$message, 'auth'=> self::generateRemoteUserToken(), 'data'=>$data);
        return Zend_Json::encode($response);
    }
    
    public static function decode($response) {
        $body = Zend_Json::decode($response);
        $auth = $body['auth'];
        if(self::validateCreationUser($auth['user'], $auth['password'], $auth['token'])) {
            if($body['status'] == self::STATUS_CODE_SUCCESS) {
                return (!empty($body['data'])) ? $body['data'] : self::STATUS_CODE_SUCCESS_LABEL;
            }else {
                throw new Zend_Controller_Action_Exception($body['message'], $body['status']);
            }
        }else {
            throw new Zend_Controller_Action_Exception(self::STATUS_CODE_UNAUTH_LABEL, self::STATUS_CODE_UNAUTH);
        }
    }
    
    private static function validateCreationUser($user, $password, $token) {
        $uId = sha1(Application_Model_Cache_Config::getConfig('REMOTE_API_SITE_USER').self::SECRET_KEY.$token);
        $pwd = sha1(Application_Model_Cache_Config::getConfig('REMOTE_API_SITE_PASSWORD').self::SECRET_KEY.$token);
        return ($user == $uId && $password == $pwd) ? true : false;
    }
    
    private static function generateRemoteUserToken() {
        $token = sha1(rand(1, 99999999). time());
        $uId = sha1(Application_Model_Cache_Config::getConfig('CREATION_API_USER').self::SECRET_KEY.$token);
        $pwd = sha1(Application_Model_Cache_Config::getConfig('CREATION_API_PASSWORD').self::SECRET_KEY.$token);
        return array('user'=>$uId, 'password'=>$pwd, 'token'=>$token);
    }
}
