<?php

class Application_Model_MenuLogic extends Application_Model_Menu
{
    public function getAllParentMenu()
    {
        $where = $this->select()->where('menu_status = ?', 'A')->where('menu_parent = ?', 0)->order('menu_order');
        return $this->fetchAll($where);
    }
    
    public function getSubMenu($id)
    {
        $where = $this->select()->where('menu_status = ?', 'A')->where('menu_parent = ?', $id)->order('menu_order');
        return $this->fetchAll($where);
    }
    
    public function fetchDataTableSelect() 
    {
        $columns = array('m.menu_title', 'm.menu_desc', 'p.menu_title', 'm.menu_status', 'action');
        $obj_data = new Application_Model_Util_Datatable((new Application_Model_MenuLogic(-1)), $columns);
        $where = $obj_data->get_where();
        $where->from(array("m"=>$this->_name, "p"=>$this->_name), 
                array("m.id", "m.menu_title", "m.menu_desc", 'p.menu_title as parent_menu', 'm.menu_status'));
        $where->joinLeft(array("p"=>  $this->_name),
                'm.menu_parent = p.id', array())
                ->setIntegrityCheck(false);
        $where->where('m.menu_status != ?', 'D');
        $where->order('m.id desc');
        $obj_data->set_where($where);
        $rows = $obj_data->fetch();
        $results = array();
        $i = 0;
        $url = new Zend_View_Helper_Url();
        $enc = new Application_Model_Util_Encrypt();
        foreach($rows as $row)
        {
            $action = '';
            if(Application_Model_RolePermissionLogic::isPermitted("Menu:Edit")) {
                $action = '<a href="'.$url->url(array("module"=>"dynasty", "controller"=>"menu", "action"=>"edit", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Edit" class="btn btn-info" /></a> ';
            }
            if(Application_Model_RolePermissionLogic::isPermitted("Menu:Delete")) {
                $action .= '<a href="'.$url->url(array("module"=>"dynasty", "controller"=>"menu", "action"=>"delete", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Delete" class="btn btn-danger" /></a>';
            }
            $results[$i] = array($row->menu_title, $row->menu_desc, (empty($row->parent_menu)) ? '<b>Parent Menu</b>' : $row->parent_menu, ($row->menu_status == 'A') ? 'Active' : 'Block', $action);
            $i += 1;
        }
        return $obj_data->configureOutput($results);
    }

    public function getMenuContent($type)
    {
        $results = array();
        if ($type == 'P') {
            $obj_page = new Application_Model_PageLogic(-1);
            foreach ($obj_page->getActivePages() as $page) {
                $results[$page->id] = $page->page_title;
            }
        } else if ($type == 'S') {
            $obj_service = new Application_Model_ServiceLogic(-1);
            foreach ($obj_service->getActiveServices() as $service) {
                $results[$service->id] = $service->service_title;
            }
        } else if ($type == 'C') {
            $obj_cat = new Application_Model_CategoryLogic(-1);
            foreach ($obj_cat->getCategoryByType('P') as $cat) {
                $results[$cat->id] = $cat->category_title;
            }
        } else if ($type == 'H') {
            $results["H"] = "Home";
        } else if ($type == 'U') {
            $results["U"] = "URL";
        } else if ($type == 'E') {
            $results["E"] = "Employee Testimonials";
        }  else if ($type == 'B') {
            $results["G"] = "Blog";
        } /*else if ($type == 'C') {
            $results[0] = 'All';
            $obj_cat = new Application_Model_CategoryLogic(-1);
            foreach ($obj_cat->getParentCategory() as $cat) {
                $results[$cat->id] = $cat->category_title;
            }
        } else if ($type == 'CT') {
            $results[0] = 'All';
            $obj_ct = new Application_Model_CityLogic(-1);
            foreach ($obj_ct->fetchOrdered() as $ct) {
                $results[$ct->id] = $ct->city_name;
            }
        }*/ else if ($type == 'CU') {
            $results["CU"] = "Contact Us";
        }
        return $results;
    }
    
    public function getMenuUrl($type, $id)
    {
        $url = null;
        if ($type == 'P') {
            $obj_page = new Application_Model_PageLogic($id);
            $url = Application_Model_Util_Util::convertToUrl($obj_page->get_page_url());
        } else if ($type == 'S') {
            $obj_service = new Application_Model_ServiceLogic($id);
            $url = 'service/'.Application_Model_Util_Util::convertToUrl($obj_service->get_service_url());
        } else if ($type == 'U') {
            $url = "url";
        } else if ($type == 'B') {
            $url = "blog";
        } else if ($type == 'C') {
            $obj_cat = new Application_Model_CategoryLogic($id);
            $url = "product/".$obj_cat->convertToUrl($obj_cat->get_category_title());
        } else if ($type == 'E') {
            $url = "testimonial";
        } else if ($type == 'H') {
            $url = "";
        } /* else if ($type == 'C') {
            if($id == 0) {
                $url = "#";
            }else {
                $obj_cat = new Application_Model_CategoryLogic($id);
                $url = 'category/'.Application_Model_Util_Util::convertToUrl($obj_cat->get_category_title());
            }
        } else if ($type == 'CT') {
            if($id == 0) {
                $url = "#";
            }else {
                $obj_ct = new Application_Model_CityLogic($id);
                $url = 'city/'.Application_Model_Util_Util::convertToUrl($obj_ct->get_city_name());
            }
        } */ else if ($type == 'CU') {
            $url = "contact-us";
        }
        return $url;
    }
}

