<?php

class Application_Model_ProductLogic extends Application_Model_Product
{
    
    public function fetchOrdered($cat = null)
    {
        $where=$this->select()->where('product_status  = ?', 'A')->order('product_name');
        if(null != $cat)
            $where->where('product_category = ?', $cat);
        return $this->fetchAll($where);
    }
    
    public function fetchDataTableSelect() 
    {
        $columns = array('product_name', 'category_title', 'product_type', 'product_qty', 'action');
        $obj_data = new Application_Model_Util_Datatable((new Application_Model_ProductLogic(-1)), $columns);
        $where = $obj_data->get_where();
        $where->from(array("p"=>$this->_name, "c"=>'asit_category'), 
                array("p.id", "p.product_name", "c.category_title", "p.product_type", "p.product_qty"));
        $where->joinLeft(array("c"=>"asit_category"),
                'p.product_category = c.id', array())
                ->setIntegrityCheck(false);
        $where->where('p.product_status != ?', 'D');
        $obj_data->set_where($where);
        $rows = $obj_data->fetch();
        $results = array();
        $i = 0;
        $url = new Zend_View_Helper_Url();
        $enc = new Application_Model_Util_Encrypt();
        foreach($rows as $row)
        {
            $action = '';
            if(Application_Model_RolePermissionLogic::isPermitted("Service:Edit")) {
                $action = '<a href="'.$url->url(array("module"=>"dynasty", "controller"=>"product", "action"=>"edit", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Edit" class="btn btn-info" /></a> ';
            }
            if(Application_Model_RolePermissionLogic::isPermitted("Service:Delete")) {
                $action .= '<a href="'.$url->url(array("module"=>"dynasty", "controller"=>"product", "action"=>"delete", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Delete" class="btn btn-danger" /></a>';
            }
            $results[$i] = array($row->product_name, $row->category_title, $row->product_type, $row->product_qty, $action);
            $i += 1;
        }
        return $obj_data->configureOutput($results);
    }
    
    public function getProductByUrl($url) {
        $where = $this->select()->where('product_url = ?', $url)->where('product_status = ?', 'A');
        $row = $this->fetchRow($where);
        if(!empty($row) && $row['id'] > 0) {
            $this->set_id($row['id']);
            $this->fetch();
            return $this;
        }
        return null;
    }
    
    public function getProductByCategoryUrl($catUrl, $limit =0) {
        $obj_cat = new Application_Model_CategoryLogic(-1);
        $catId = $obj_cat->getIdByTitle($catUrl);
        $where = $this->select()->where('product_category = ?', $catId)->where('product_status = ?', 'A');
        if($limit > 0){
            $where->limit($limit);
        }
        return $this->fetchAll($where);        
    }
    
    public function countProductUrl($url) {
        $where = $this->select()->where('product_status = ?', 'A')->where('product_url = ?', $url);
        return count($this->fetchAll($where));
    }
    
    public function generateProductUrl($url) {
        $url = strtolower(preg_replace('/[^a-zA-Z0-9]/', '-', trim($url)));
        $existRecord = $this->countPageUrl($url);
        if($existRecord > 0) {
            return $url.'-'.$existRecord;
        }else {
            return $url;
        }
    }
    
    
}

